=======================================================================================
dj_waff - A collection of extra Django Widgets and Form Fields
=======================================================================================

.. image:: https://badge.fury.io/py/dj_waff.svg
    :target: https://badge.fury.io/py/dj_waff

.. image:: https://travis-ci.org/luzfcb/dj_waff.svg?branch=master
    :target: https://travis-ci.org/luzfcb/dj_waff

dj_waff - A collection of extra Django Widgets and Form Fields

Documentation
-------------

The full documentation is at https://dj_waff.readthedocs.org.

Quickstart
----------

Install dj_waff - extra Django Widgets and Form Fields::

    pip install dj_waff

Then use it in a project::

    import dj_waff

Features
--------

* TODO

Running Tests
-------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements_test.txt
    (myenv) $ python runtests.py

Credits
-------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-djangopackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
